@@ -1,4 +1,4 @@
-# $Id: Clustalw.pm 16221 2009-09-30 04:30:42Z cjfields $
+# $Id$
 #
 # BioPerl module for Bio::Tools::Run::Alignment::Clustalw
 #
@@ -337,7 +337,7 @@ Report bugs to the Bioperl bug tracking system to help us keep track
 the bugs and their resolution.  Bug reports can be submitted via the
 web:
 
-  http://bugzilla.open-bio.org/
+  http://redmine.open-bio.org/projects/bioperl/
 
 =head1 AUTHOR -  Peter Schattner
 
@@ -441,7 +441,7 @@ sub version {
 
     return undef unless $self->executable;
     my $prog = $self->executable;
-    my $string = `$prog --` ;
+    my $string = `$prog -- 2>&1` ;
     $string =~ /\(?([\d.]+)\)?/xms;
     return $1 || undef;
 }
@@ -660,6 +660,7 @@ sub footprint {
     for my $i (1..($length - $slice_size + 1)) {
         my $slice = $simplealn->slice($i, ($i + $slice_size - 1), 1);
         my $tree = $self->tree($slice);
+        $self->throw("No tree returned") unless defined $tree;
         my $slice_length = $tree->total_branch_length;
         
         $slice_length <= $threshold ? ($below = 1) : ($below = 0);
@@ -707,7 +708,7 @@ sub _run {
             $command = '';
         }
         else { 
-            $instring = " -infile=$infile1";
+            $instring = " -infile=". '"' . $infile1 . '"';
         }
         $param_string .= " $infile2";
     }
@@ -730,7 +731,7 @@ sub _run {
             $command = '';
         }
         else { 
-            $instring = " $infile1";
+            $instring = " -infile=". '"' . $infile1 . '"';
         }
     	$param_string .= " $infile2";
         
@@ -751,7 +752,7 @@ sub _run {
     my $output = $self->output || 'gcg';
     $self->debug( "Program ".$self->executable."\n");
     my $commandstring = $self->executable." $command"." $instring"." -output=$output". " $param_string";
-    $self->debug( "clustal command = $commandstring");
+    $self->debug( "clustal command = $commandstring\n");
     
     open(my $pipe, "$commandstring |") || $self->throw("ClustalW call ($commandstring) failed to start: $? | $!");
     my $score;
@@ -920,7 +921,7 @@ sub _setparams {
         close($tfh);
         undef $tfh;
         $self->outfile($outfile);
-        $param_string .= " -outfile=$outfile" ;
+        $param_string .= " -outfile=\"$outfile\"" ;
     }
     
     $param_string .= ' 2>&1';
